==> openjdk13-13.0.13_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_ar_SA.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_ar_SA extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AC", "\u062c\u0632\u064a\u0631\u0629 \u0623\u0633\u064a\u0646\u0634\u064a\u0646" },
            { "BS", "\u062c\u0632\u0631 \u0627\u0644\u0628\u0647\u0627\u0645\u0627" },
            { "EA", "\u0633\u0628\u062a\u0629 \u0648\u0645\u0644\u064a\u0644\u064a\u0629" },
            { "MO", "\u0645\u0627\u0643\u0627\u0648 \u0627\u0644\u0635\u064a\u0646\u064a\u0629 (\u0645\u0646\u0637\u0642\u0629 \u0625\u062f\u0627\u0631\u064a\u0629 \u062e\u0627\u0635\u0629)" },
            { "MS", "\u0645\u0648\u0646\u062a\u064a\u0633\u064a\u0631\u0627\u062a" },
            { "UY", "\u0623\u0648\u0631\u0648\u063a\u0648\u0627\u064a" },
            { "gn", "\u0627\u0644\u063a\u0648\u0631\u0627\u0646\u064a\u0629" },
            { "lo", "\u0627\u0644\u0644\u0627\u0648\u0648" },
            { "sh", "\u0627\u0644\u0643\u0631\u0648\u0627\u062a\u064a\u0629 \u0627\u0644\u0635\u0631\u0628\u064a\u0629" },
            { "sw", "\u0627\u0644\u0633\u0648\u0627\u062d\u064a\u0644\u064a\u0629" },
            { "te", "\u0627\u0644\u062a\u064a\u0644\u0648\u062c\u0648" },
            { "ti", "\u0627\u0644\u062a\u064a\u063a\u0631\u064a\u0646\u064a\u0629" },
            { "arn", "\u0627\u0644\u0645\u0627\u0628\u0648\u062f\u0648\u0646\u062c\u0648\u0646\u064a\u0629" },
            { "hsb", "\u0635\u0648\u0631\u0628\u064a\u0627 \u0627\u0644\u0639\u0644\u064a\u0627" },
            { "sma", "\u0633\u0627\u0645\u064a \u0627\u0644\u062c\u0646\u0648\u0628\u064a\u0629" },
            { "sw_CD", "\u0627\u0644\u0633\u0648\u0627\u062d\u064a\u0644\u064a\u0629 \u0627\u0644\u0643\u0648\u0646\u063a\u0648\u0644\u064a\u0629" },
        };
        return data;
    }
}

==> openjdk15-15.0.9_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_ar_SA.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_ar_SA extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AC", "\u062c\u0632\u064a\u0631\u0629 \u0623\u0633\u064a\u0646\u0634\u064a\u0646" },
            { "EA", "\u0633\u0628\u062a\u0629 \u0648\u0645\u0644\u064a\u0644\u064a\u0629" },
            { "MO", "\u0645\u0627\u0643\u0627\u0648 \u0627\u0644\u0635\u064a\u0646\u064a\u0629 (\u0645\u0646\u0637\u0642\u0629 \u0625\u062f\u0627\u0631\u064a\u0629 \u062e\u0627\u0635\u0629)" },
            { "MS", "\u0645\u0648\u0646\u062a\u064a\u0633\u064a\u0631\u0627\u062a" },
            { "UY", "\u0623\u0648\u0631\u0648\u063a\u0648\u0627\u064a" },
            { "gn", "\u0627\u0644\u063a\u0648\u0631\u0627\u0646\u064a\u0629" },
            { "lo", "\u0627\u0644\u0644\u0627\u0648\u0648" },
            { "sh", "\u0627\u0644\u0643\u0631\u0648\u0627\u062a\u064a\u0629 \u0627\u0644\u0635\u0631\u0628\u064a\u0629" },
            { "sw", "\u0627\u0644\u0633\u0648\u0627\u062d\u064a\u0644\u064a\u0629" },
            { "te", "\u0627\u0644\u062a\u064a\u0644\u0648\u062c\u0648" },
            { "ti", "\u0627\u0644\u062a\u064a\u063a\u0631\u064a\u0646\u064a\u0629" },
            { "arn", "\u0627\u0644\u0645\u0627\u0628\u0648\u062f\u0648\u0646\u062c\u0648\u0646\u064a\u0629" },
            { "hsb", "\u0635\u0648\u0631\u0628\u064a\u0627 \u0627\u0644\u0639\u0644\u064a\u0627" },
            { "sma", "\u0633\u0627\u0645\u064a \u0627\u0644\u062c\u0646\u0648\u0628\u064a\u0629" },
            { "sw_CD", "\u0627\u0644\u0633\u0648\u0627\u062d\u064a\u0644\u064a\u0629 \u0627\u0644\u0643\u0648\u0646\u063a\u0648\u0644\u064a\u0629" },
            { "ar_001", "\u0627\u0644\u0639\u0631\u0628\u064a\u0629 \u0627\u0644\u0631\u0633\u0645\u064a\u0629 \u0627\u0644\u062d\u062f\u064a\u062b\u0629" },
        };
        return data;
    }
}
